# Menu Migration

The Menu Migration module facilitates the import and export of menu hierarchies
from one Drupal copy to another one.

Out of the box, the module allows the following:
- Export menu hierarchies to a file in the codebase
- Import menu hierarchies from a file in the codebase
- Export menu hierarchies to a downloadable file
- Import menu hierarchies from an uploaded file

The module only supports **MenuLinkContent** menu items (the ones that are
manually created), any other menu items will not be exported/imported (e.g.
Views, Taonomy Menu etc.). It currently offers one format: JSON.

The export destinations, import sources and formats can be extended through the
Plugin system.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/menu_migration).

For a detailed documentation, visit the
[module documentation](https://www.drupal.org/docs/extending-drupal/contributed-modules/contributed-module-documentation/menu-migration-import-export).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/menu_migration).

Chat, news, support & feedback in the dedicated [Slack channel](https://drupal.slack.com/archives/C079PP3DMJP).

## Table of contents

- Requirements
- Installation
- Configuration
- Drush integration
- Troubleshooting
- Maintainers

## Requirements

File permissions actions might be required on the server for the Codebase Export
Destination.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

There are two configuration areas that are available:
1. Export Types - allows defining export types that can later trigger exports
2. Import Types - allows defining import types that can later trigger imports

### Defining an export type

In order to perform a menu export, an export type needs to be created.
1. Navigate to Configuration → Development → Menu Migration → Export Types
2. Click on _Add export type_ and fill out the form
3. The _Export type name_ can be anything relevant to you
4. The machine name will be the ID of the export type and will be used with
Drush
5. The _Export Destination_ can have one of the following values: Codebase or
Download
6. The Codebase exports the menus to the file system, and the Download generates
a downloadable file
7. Set the _Format_ to JSON (the only available option at the moment)
8. Select the _Menus_ that you wish to export
9. Fill out any other field depending on the _Export Destination_ choice.

### Export menu

1. Navigate to Configuration → Development → Menu Migration → Export Types
2. Here you have a listing of the available export types
3. In the _Operations_ column, click on _Export_ for one of the export types
4. You will be presented with a confirmation form that details all information
   about the export process & location
5. If you are satisfied with the conditions, click on export and that's it

### Defining an import type

In order to perform a menu import, an import type needs to be created.
1. Navigate to Configuration → Development → Menu Migration → Import Types
2. Click on _Add Import type_ and fill out the form
3. The _Import type name_ can be anything relevant to you
4. The machine name will be the ID of the Import type and will be used with
   Drush
5. The _Import Source_ can have one of the following values: Codebase or
   File Upload.
6. The Codebase Imports the menus from the file system, and the File Upload
   imports them from an uploaded file
7. Set the _Format_ to JSON (the only available option at the moment)
8. Select the _Menus_ that you wish to Import
9. Fill out any other field depending on the _Import Source_ choice.

### Import menu

1. Navigate to Configuration → Development → Menu Migration → Import Types
2. Here you have a listing of the available import types
3. In the _Operations_ column, click on _Import_ for one of the export types
4. You will be presented with a confirmation form that details all information
   about the import process & source
5. If you are satisfied with the conditions, click on export and that's it

## Drush integration

Menu migration provides four Drush commands for managing imports and exports.
You can import one or more menus at a time through your already defined export
types and import types.

### Export Command

Performs the export for the given export type ID. Requires confirmation.

```shell
# Export the Export Type with ID my_export_id.
drush mme my_export_id
# Export the Export Type with ID my_export_id, and skip confirmation question.
drush mme my_export_id -y
```

### Export List Command

Lists all the available export types that support Drush.

```shell
# List all the available export entities
drush mmel
```

### Import Command

Performs the import for the given export type ID. Requires confirmation.

```shell
# Import the Import Type with ID my_import_id.
drush mmi my_import_id
# Import the Import Type with ID my_import_id, and skip the confirmation question.
drush mmi my_import_id -y
```

### Import List Command

Lists all the available import types that support Drush.

```shell
# List all the available import entities
drush mmil
```

## Troubleshooting

If you're getting errors that the menus can't be exported, please make
sure that the target directory has writing access by the server user that
is about to execute the exports when using the Codebase destination.

If the menu item hierarchy is messed up after import, make sure menu items are
only added via the menu UI (for example "Main navigation") and not a View.

## Maintainers

Cristina B. - [bbu23](https://www.drupal.org/u/bbu23)
