<?php

namespace Drupal\menu_migration;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Builds a listing of export type entities.
 */
class ExportTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['label'] = $this->t('Name');
    $header['format'] = $this->t('Format');
    $header['destination'] = $this->t('Destination');
    $header['menus'] = $this->t('Menus');
    $header['cli'] = $this->t('Supports Drush');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id'] = $entity->id();
    $row['label'] = $entity->label();
    $row['format'] = $entity->getFormat();
    $row['destination'] = $entity->getDestination();
    $row['menus'] = implode(', ', $entity->getMenus());
    $row['cli'] = $entity->handleCli() ? $this->t('Yes') : $this->t('No');
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $export = [
      'title' => $this->t('Export'),
      'weight' => -50,
      'url' => $entity->toUrl('export-form'),
    ];

    return ['export' => $export] + parent::getDefaultOperations($entity);
  }

}
