<?php

namespace Drupal\menu_migration;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Defines a class to build a listing of import type entities.
 *
 * @see \Drupal\menu_migration\Entity\ImportType
 */
class ImportTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['label'] = $this->t('Name');
    $header['source'] = $this->t('Source');
    $header['format'] = $this->t('Format');
    $header['menus'] = $this->t('Menus');
    $header['cli'] = $this->t('Supports Drush');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id'] = $entity->id();
    $row['label'] = $entity->label();
    $row['source'] = $entity->getSource();
    $row['format'] = $entity->getFormat();
    $row['menus'] = implode(', ', $entity->getMenus());
    $row['cli'] = $entity->handleCli() ? $this->t('Yes') : $this->t('No');
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $import = [
      'title' => $this->t('Import'),
      'weight' => -50,
      'url' => $this->ensureDestination($entity->toUrl('import-form')),
    ];

    return ['import' => $import] + parent::getDefaultOperations($entity);
  }

}
